==> spip_3.0.8.orig.tar.xz: spip-3.0.8.orig/plugins-dist/petitions/lang/petitions_ar.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=ar
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'alerte_confirmer_suppression_signatures' => 'سوف تحذف كل تواقيع هذه العريضة. هل انت متأكد من ذلك؟',
	'aucune_signature' => 'لا توجد تواقيع',

	// B
	'bouton_checkbox_envoi_message' => 'إمكان بعث رسالة ',
	'bouton_checkbox_indiquer_site' => 'يجب تحديد موقع على النسيج',
	'bouton_checkbox_signature_unique_email' => 'توقيع واحد فقط لكل عنوان بريدي',
	'bouton_checkbox_signature_unique_site' => 'توقيع واحد فقط لكل موقع',

	// F
	'filtre' => 'مرشح:',
	'form_pet_adresse_site' => 'عنوان موقعك',
	'form_pet_aucune_signature' => 'لا يوجد أي توقيع يناسب هذا المعرف...',
	'form_pet_confirmation' => 'الرجاء تأكيد توقيعك:',
	'form_pet_deja_signe' => 'سبق ووقعت هذا النص.',
	'form_pet_envoi_mail_confirmation' => 'لقد تم إرسال بريد إلكتروني للتأكيد إلى @email@. يجب عليك أن تزور العنوان المذكور في الرسالة للتصديق على توقيعك.',
	'form_pet_mail_confirmation' => 'مرحباً،

طلبت توقيع العريضة:
@titre@.

لقد أدخلت المعلومات التالية:
    الاسم: @nom_email@
    الموقع: @nom_site@ - @url_site@

مهم جداً...
للتصديق على توقيعك يكفي أن تتصل
بالعنوان أدناه (إذا لم تفعل، سيتم
رفض طلبك):

    @url@


شكراً لمساهمتك

',
	'form_pet_message_commentaire' => 'أي رسالة أو تعليق؟',
	'form_pet_nom_site2' => 'اسم موقعك',
	'form_pet_probleme_liens' => 'الرجاء إعادة إدخال رسالتك بعد حذف كل روابط هايبرتكست.',
	'form_pet_probleme_technique' => 'مشكلة تقنية، التوقيعات معلقة مؤقتاً.',
	'form_pet_signature_validee' => 'توقيعك صالح. شكراً!',
	'form_pet_site_deja_enregistre' => 'سبق تسجيل هذا الموقع',
	'form_pet_url_invalide' => 'العنوان الذي أدخلته غير صالح.',
	'form_pet_votre_email' => 'عنوانك الإلكتروني',
	'form_pet_votre_nom' => 'اسمك',
	'form_pet_votre_site' => 'إذا كان لديك موقع، قم بإدخاله أدناه',

	// I
	'icone_relancer_signataire' => 'إعادة إنعاش التوقيع',
	'icone_relancer_signataires' => 'إعادة إنعاش التواقيع',
	'icone_suivi_petitions' => 'متابعة\\إدارة العرائض',
	'icone_supprimer_signature' => 'حذف هذا التوقيع',
	'icone_supprimer_signatures' => 'حذف التواقيع',
	'icone_valider_signature' => 'التصديق على هذا التوقيع',
	'icone_valider_signatures' => 'التصديق على التواقيع',
	'info_adresse_email' => 'عنوان البريد الالكتروني :',
	'info_fonctionnement_petition' => 'كيفية عمل العريضة:',
	'info_signature_supprimee' => 'توقيع محذوف',
	'info_signature_supprimee_erreur' => 'خطأ: معلومات الحذف هذه لا تناسب اي توقيع',
	'info_site_web' => 'الموقع:',
	'info_texte_message' => 'نص مشاركتك:',

	// L
	'lien_reponse_article' => 'الرد على المقال',

	// N
	'nombre_signatures' => '@nb@ توقيع',

	// S
	'sans_nom' => 'مجهول',
	'signatures_article' => 'تواقيع المقال:',
	'signatures_aucune' => 'لا يوجد',
	'signatures_meme_auteur' => 'تواقيع عائدة للمؤلف نفسه',
	'signatures_meme_site' => 'تواقيع عائدة للموقع نفسه',
	'signatures_poubelle' => 'محذوفة',
	'signatures_prop' => 'قيد الانتظار',
	'signatures_publie' => 'مصدقة',
	'signatures_recherche_label' => 'بحث عن التوقيعات:',
	'signatures_selection' => 'Sélectionner les signatures :', # NEW
	'signatures_toutes' => 'الكل',
	'statut_poubelle' => 'محذوف',
	'statut_prop' => 'بانتظار التصديق',
	'statut_publie' => 'مصدق',

	// T
	'texte_descriptif_petition' => 'وصف العريضة',
	'titre_page_controle_petition' => 'متابعة العرائض',
	'titre_petition' => 'عريضة',
	'titre_petitions' => 'عرائض',
	'titre_selection_action' => 'التحديد',
	'titre_signatures_attente' => 'تواقيع بانتظار التصديق',
	'titre_signatures_publie' => 'تواقيع مصدقة',
	'titre_suivi_petition' => 'متابعة العرائض',
	'tout_voir' => 'عرض كل التواقيع',

	// U
	'une_signature' => 'توقيع واحد',

	// V
	'voir_signatures_objet' => 'عرض التواقيع'
);

?>

==> spip_3.1~21100.orig.tar.xz: spip-3.1~21100.orig/plugins-dist/petitions/lang/petitions_ar.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=ar
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'alerte_confirmer_suppression_signatures' => 'سوف تحذف كل تواقيع هذه العريضة. هل انت متأكد من ذلك؟',
	'aucune_signature' => 'لا توجد تواقيع',

	// B
	'bouton_checkbox_envoi_message' => 'إمكان بعث رسالة ',
	'bouton_checkbox_indiquer_site' => 'يجب تحديد موقع على النسيج',
	'bouton_checkbox_signature_unique_email' => 'توقيع واحد فقط لكل عنوان بريدي',
	'bouton_checkbox_signature_unique_site' => 'توقيع واحد فقط لكل موقع',
	'bouton_radio_activer_petition' => 'تفعيل العريضة',
	'bouton_radio_pas_petition' => 'بدون عرائض',
	'bouton_radio_petition_activee' => 'تم تفعيل العريضة',
	'bouton_radio_supprimer_petition' => 'حذف العريضة',

	// F
	'filtre' => 'مرشح:',
	'form_pet_adresse_site' => 'عنوان موقعك',
	'form_pet_aucune_signature' => 'لا يوجد أي توقيع يناسب هذا المعرف...',
	'form_pet_confirmation' => 'الرجاء تأكيد توقيعك:',
	'form_pet_deja_signe' => 'سبق ووقعت هذا النص.',
	'form_pet_envoi_mail_confirmation' => 'لقد تم إرسال بريد إلكتروني للتأكيد إلى @email@. يجب عليك أن تزور العنوان المذكور في الرسالة للتصديق على توقيعك.',
	'form_pet_mail_confirmation' => 'مرحباً،

طلبت توقيع العريضة:
@titre@.

لقد أدخلت المعلومات التالية:
    الاسم: @nom_email@
    الموقع: @nom_site@ - @url_site@

مهم جداً...
للتصديق على توقيعك يكفي أن تتصل
بالعنوان أدناه (إذا لم تفعل، سيتم
رفض طلبك):

    @url@


شكراً لمساهمتك

',
	'form_pet_message_commentaire' => 'أي رسالة أو تعليق؟',
	'form_pet_nom_site2' => 'اسم موقعك',
	'form_pet_probleme_liens' => 'الرجاء إعادة إدخال رسالتك بعد حذف كل روابط هايبرتكست.',
	'form_pet_probleme_technique' => 'مشكلة تقنية، التوقيعات معلقة مؤقتاً.',
	'form_pet_signature_validee' => 'توقيعك صالح. شكراً!',
	'form_pet_site_deja_enregistre' => 'سبق تسجيل هذا الموقع',
	'form_pet_url_invalide' => 'العنوان الذي أدخلته غير صالح.',
	'form_pet_votre_email' => 'عنوانك الإلكتروني',
	'form_pet_votre_nom' => 'اسمك',
	'form_pet_votre_site' => 'إذا كان لديك موقع، قم بإدخاله أدناه',

	// I
	'icone_relancer_signataire' => 'إعادة إنعاش التوقيع',
	'icone_relancer_signataires' => 'إعادة إنعاش التواقيع',
	'icone_suivi_petitions' => 'متابعة\\إدارة العرائض',
	'icone_supprimer_signature' => 'حذف هذا التوقيع',
	'icone_supprimer_signatures' => 'حذف التواقيع',
	'icone_valider_signature' => 'التصديق على هذا التوقيع',
	'icone_valider_signatures' => 'التصديق على التواقيع',
	'info_adresse_email' => 'عنوان البريد الالكتروني :',
	'info_fonctionnement_petition' => 'كيفية عمل العريضة:',
	'info_signature_supprimee' => 'توقيع محذوف',
	'info_signature_supprimee_erreur' => 'خطأ: معلومات الحذف هذه لا تناسب اي توقيع',
	'info_site_web' => 'الموقع:',
	'info_texte_message' => 'نص مشاركتك:',

	// L
	'lien_reponse_article' => 'الرد على المقال',

	// N
	'nombre_signatures' => '@nb@ توقيع',

	// S
	'sans_nom' => 'مجهول',
	'signatures_article' => 'تواقيع المقال:',
	'signatures_aucune' => 'لا يوجد',
	'signatures_meme_auteur' => 'تواقيع عائدة للمؤلف نفسه',
	'signatures_meme_site' => 'تواقيع عائدة للموقع نفسه',
	'signatures_poubelle' => 'محذوفة',
	'signatures_prop' => 'قيد الانتظار',
	'signatures_publie' => 'مصدقة',
	'signatures_recherche_label' => 'بحث عن التوقيعات:',
	'signatures_selection' => 'تحديد التواقيع:',
	'signatures_toutes' => 'الكل',
	'statut_poubelle' => 'محذوف',
	'statut_prop' => 'بانتظار التصديق',
	'statut_publie' => 'مصدق',

	// T
	'texte_descriptif_petition' => 'وصف العريضة',
	'titre_page_controle_petition' => 'متابعة العرائض',
	'titre_petition' => 'عريضة',
	'titre_petitions' => 'عرائض',
	'titre_selection_action' => 'التحديد',
	'titre_signatures_attente' => 'تواقيع بانتظار التصديق',
	'titre_signatures_publie' => 'تواقيع مصدقة',
	'titre_suivi_petition' => 'متابعة العرائض',
	'tout_voir' => 'عرض كل التواقيع',

	// U
	'une_signature' => 'توقيع واحد',

	// V
	'voir_signatures_objet' => 'عرض التواقيع'
);

?>
